==> sudoku-solver-tek-1.0.tar.gz: sudoku-solver-tek-1.0/README.md <==
[![Build Status](https://travis-ci.com/TralahM/sudoku-solver.svg?branch=master)](https://travis-ci.com/TralahM/sudoku-solver)
[![License: MIT](https://img.shields.io/badge/License-MIT-red.svg)](https://opensource.org/licenses/MIT)
[![Organization](https://img.shields.io/badge/Org-TralahTek-blue.svg)](https://github.com/TralahTek)
[![made-with-python](https://img.shields.io/badge/Made%20with-Python-1f425f.svg)](https://www.python.org/)
[![HitCount](http://hits.dwyl.io/TralahM/sudoku-solver.svg)](http://dwyl.io/TralahM/sudoku-solver)
[![Inline Docs](http://inch-ci.org/github/TralahM/sudoku-solver.svg?branch=master)](http://inch-ci.org/github/TralahM/sudoku-solver)
[![PyPI pyversions](https://img.shields.io/pypi/pyversions/ansicolortags.svg)](https://pypi.python.org/pypi/ansicolortags/)
[![PRs Welcome](https://img.shields.io/badge/PRs-welcome-brightgreen.svg?style=flat-square)](https://github.com/TralahM/pull/)
[![GitHub pull-requests](https://img.shields.io/github/issues-pr/Naereen/StrapDown.js.svg)](https://gitHub.com/TralahM/sudoku-solver/pull/)
[![GitHub version](https://badge.fury.io/gh/Naereen%2FStrapDown.js.svg)](https://github.com/TralahM/sudoku-solver).

# sudoku-solver.

# Description

[![TralahM](https://img.shields.io/badge/Engineer-TralahM-blue.svg?style=for-the-badge)](https://github.com/TralahM)
[![TralahM](https://img.shields.io/badge/Maintainer-TralahM-green.svg?style=for-the-badge)](https://github.com/TralahM)

# Documentation
Solve Sudoku Puzzles with this python script

The Script takes a csv file as input as prints out the solution to the sudoku puzzle to the console.
The Csv must be of 9 lines total no blank lines and the values are separated only by commas(no spaces).
Empty cells are represented with a zero.

## Example File

```csv
3,0,6,5,0,8,4,0,0
5,2,0,0,0,0,0,0,0
0,8,7,0,0,0,0,3,1
0,0,3,0,1,0,0,8,0
9,0,0,8,6,3,0,0,5
0,5,0,0,9,0,6,0,0
1,3,0,0,0,0,2,5,0
0,0,0,0,0,0,0,7,4
0,0,5,2,0,6,3,0,0
```

[Read the Docs](https://sudoku-solver.readthedocs.io)



## Running and Installation

```console
git clone https://github.com/TralahM/sudoku-solver.git
cd sudoku-solver
python solver.py -f puzzles/sample_sudoku.csv
```

## Install the Script from pypi using pip

```console
pip install sudoku-solver
sudoku-solver -f somepuzzle.csv
```

# Contributing
[See the Contributing File](CONTRIBUTING.rst)


[See the Pull Request File](PULL_REQUEST_TEMPLATE.md)


# Support

# LICENCE

[Read the license here](LICENSE)


# Acknowledgements

==> sudoku-solver-tek-1.1.tar.gz: sudoku-solver-tek-1.1/README.md <==
[![Build Status](https://travis-ci.com/TralahM/sudoku-solver.svg?branch=master)](https://travis-ci.com/TralahM/sudoku-solver)
[![License: MIT](https://img.shields.io/badge/License-MIT-red.svg)](https://opensource.org/licenses/MIT)
[![Organization](https://img.shields.io/badge/Org-TralahTek-blue.svg)](https://github.com/TralahTek)
[![made-with-python](https://img.shields.io/badge/Made%20with-Python-1f425f.svg)](https://www.python.org/)
[![HitCount](http://hits.dwyl.io/TralahM/sudoku-solver.svg)](http://dwyl.io/TralahM/sudoku-solver)
[![Inline Docs](http://inch-ci.org/github/TralahM/sudoku-solver.svg?branch=master)](http://inch-ci.org/github/TralahM/sudoku-solver)
[![PyPI pyversions](https://img.shields.io/pypi/pyversions/ansicolortags.svg)](https://pypi.python.org/pypi/ansicolortags/)
[![PRs Welcome](https://img.shields.io/badge/PRs-welcome-brightgreen.svg?style=flat-square)](https://github.com/TralahM/pull/)
[![GitHub pull-requests](https://img.shields.io/github/issues-pr/Naereen/StrapDown.js.svg)](https://gitHub.com/TralahM/sudoku-solver/pull/)
[![GitHub version](https://badge.fury.io/gh/Naereen%2FStrapDown.js.svg)](https://github.com/TralahM/sudoku-solver).

# sudoku-solver.

# Description

[![TralahM](https://img.shields.io/badge/Engineer-TralahM-blue.svg?style=for-the-badge)](https://github.com/TralahM)
[![TralahM](https://img.shields.io/badge/Maintainer-TralahM-green.svg?style=for-the-badge)](https://github.com/TralahM)

# Documentation
Solve Sudoku Puzzles with this python script

The Script takes a csv file as input as prints out the solution to the sudoku puzzle to the console.
The Csv must be of 9 lines total no blank lines and the values are separated only by commas(no spaces).
Empty cells are represented with a zero.

## Example File

```csv
3,0,6,5,0,8,4,0,0
5,2,0,0,0,0,0,0,0
0,8,7,0,0,0,0,3,1
0,0,3,0,1,0,0,8,0
9,0,0,8,6,3,0,0,5
0,5,0,0,9,0,6,0,0
1,3,0,0,0,0,2,5,0
0,0,0,0,0,0,0,7,4
0,0,5,2,0,6,3,0,0
```

[Read the Docs](https://sudoku-solver.readthedocs.io)



## Running and Installation

```console
git clone https://github.com/TralahM/sudoku-solver.git
cd sudoku-solver
python solver.py -f puzzles/sample_sudoku.csv
```

## Install the Script from pypi using pip

```console
pip install sudoku-solver-tek
sudoku-solver -f somepuzzle.csv
```

# Contributing
[See the Contributing File](CONTRIBUTING.rst)


[See the Pull Request File](PULL_REQUEST_TEMPLATE.md)


# Support

# LICENCE

[Read the license here](LICENSE)


# Acknowledgements
